@@ -7,7 +7,7 @@ import configparser
 def config2json(path):
     """
     读取配置文件为json
-    :param path: 配置文件路径，eg: config.ini/config.conf/config.cfg
+    :param path: 配置文件路径,eg: config.ini/config.conf/config.cfg
     :return 返回json eg: {"项名":{"选项":"值"}
     """
     _dict = {}
@@ -23,7 +23,7 @@ def config2json(path):
 def json2config(path, _dict):
     """
     写入json格式配置到文件
-    :param path: 配置文件路径，eg: config.ini/config.conf/config.cfg
+    :param path: 配置文件路径,eg: config.ini/config.conf/config.cfg
     :param _dict: json格式 eg: {"项名":{"选项":"值"}
     """
     conf = configparser.ConfigParser()
