@@ -15,21 +15,17 @@ def file2md5(_file):
         return md5obj.hexdigest()
 
 
-def str2md5(_str):
+def str2md5(_str, encoding='utf8'):
     ''''
     获取字符串md5
     :param _str: 字符串
     '''
-    md5obj = hashlib.md5()
-    md5obj.update(_str.encode('utf8'))
-    return md5obj.hexdigest()
+    return hashlib.md5(_str.encode(encoding)).hexdigest()
 
 
-def str2sha256(_str):
+def str2sha256(_str, encoding='utf8'):
     ''''
     获取字符串sha256
     :param _str: 字符串
     '''
-    sha256 = hashlib.sha256()
-    sha256.update(_str.encode('utf-8'))
-    return sha256.hexdigest()
+    return hashlib.sha256(_str.encode(encoding)).hexdigest()
